//************************************************************
//  University of Patras
//	Department of Electrical Engineering & Computer Technology
//
//	Course: Parallel Programming in AI
//	Week 05: OpenMp
//
//  Description: Simple examples  in openMP
//  	pi06.c: Estimation of pi replacing sqrt by pow
//	Author: Evangelos Dermatas
//	v0.1
/*
*********************************************************************
gcc -v:	gcc version 7.4.0 (Ubuntu 7.4.0-1ubuntu1~18.04.1)
OS: 	Linux Ubuntu 18.04
CPU:	8-core, Intel(R) Core(TM) i7-2630QM CPU @ 2.00GHz, 3991 BogoMips
*********************************************************************
Compiling:	gcc pi06.c -o pi06 -fopenmp -O3 -ffast-math -lm

Executing:	./pi06

pi= 3.14159265558978928

real	0m15.524s
user	2m1.529s
sys	0m0.017s


Previous version pi05
pi= 3.14159265558977729

real	0m1.035s
user	0m8.141s
sys	0m0.000s

Previous version pi03
pi= 3.14159265558978928

real	0m2.045s
user	0m16.241s
sys	0m0.004s


*/
//************************************************************

#include <stdio.h>
#include <stdlib.h>
#include <omp.h>
#include <math.h>


#define N 1000000000

// **************************************************************
int main(void)
{
	double sum = 0 ;
	double step ;

	step = 1.0/N ;

#pragma omp parallel for simd reduction(+:sum)
	for( int i = 0 ; i < N ; i++ ) {
		double x = i * step ;
		sum += pow( 1.0 - x*x, 0.5 ) ;
		}

	printf( "pi=%20.17lf\n", 4.0 * sum * step ) ;
	return 0 ;
}
